@@ -2,7 +2,7 @@
 
 void Alternatives::checkCase(string &head, size_t *idx) const
 {
-    if ((d_arg.option('i') & 1) != 0)   // even number of --icase specs
+    if ((d_options.icase() & 1) != 0)   // even number of --icase specs
     {
         string mold("[..]");
         int ch = head[*idx];
@@ -14,6 +14,6 @@ void Alternatives::checkCase(string &head, size_t *idx) const
             *idx += 4;
             return;
         }
-	}
+    }
     ++*idx;
 }
