@@ -9,12 +9,12 @@ string Alternatives::determineInitialDirectory()
     switch (d_command.action())
     {
         case Command::FROM_CONFIG:
-            cwd = d_home ? d_homeDir : string("/");
+            cwd = d_fromHome ? d_options.homeDir() : string("/");
             rescan = true;
         break;
 
         case Command::FROM_HOME:
-            cwd = d_homeDir;
+            cwd = d_options.homeDir();
         break;
 
         case Command::FROM_ROOT:
@@ -40,12 +40,12 @@ string Alternatives::determineInitialDirectory()
         break;
     }
 
-    if (d_addRoot != FALSE && (!d_home || !rescan))
+    if (d_addRoot != NEVER and (!d_fromHome || !rescan))
     {
         imsg << "Search does not start at the home dir: "
                 "no additional search from the root" << endl;
 
-        d_addRoot = FALSE;
+        d_addRoot = NEVER;
     }
 
     imsg << "Resolved Cwd as: " << cwd << endl;
