@@ -15,8 +15,12 @@ Alternatives::ViableResult Alternatives::generalizedGlob(string initial,
         searchCmd.resize(searchCmd.length() - 1);       // remove trailing /
 
 
-    imsg << "Merged search command: `" << searchCmd << "'\n"
-            "Starts at `" << initial << '\'' << endl;
+    if (searchCmd.empty())
+        imsg << "No merged search command\n";
+    else
+        imsg << "Merged search command: `" << searchCmd << "'\n";
+
+    imsg << "Searching starts at `" << initial << '\'' << endl;
 
     globHead(initial, searchCmd, context);
 
