@@ -3,22 +3,16 @@
 Command::Command()
 :
     d_action(FROM_HOME),
-    d_parent(0)
+    d_parent(0),
+    d_homedirChar(Options::instance().homedirChar())
 {
-    ArgConfig &argConfig = ArgConfig::instance();
-
-    if (string value; argConfig.option(&value, "homedir-char"))
-    {
-        d_homedirChar = value[0];
-        if ("0123456789/"s.find(d_homedirChar) != string::npos)
-            throw Exception{ 1 } << "Character `" << value[0] <<
-                                    "' cannot be used as homedir-character";
-    }
-
-    concatArgs();
+    concatArgs();       // concatenate arguments, separating them by /
+                        // characters
 
     determineAction();
 
+                        // store the individual arguments in the base class
+                        // (string vector)
     String::split(this, d_arguments, s_separators);
 
     // When are the elements of the first argument changed into initial chars
@@ -29,17 +23,8 @@ Command::Command()
     // Can't 2 and 3 be combined to: size() == 1 ?
 //    if (!subSpecs && size() && ArgConfig::instance().nArgs() == 1)
 
-    if (size() == 1)
-    {
-        for_each(
-            front().begin() + 1, front().end(),
-            [&](char ch)
-            {
-                this->push_back(string(1, ch));
-            }
-        );
-        front().resize(1);
-    }
+    splitBase();            // split the base class if it contains only
+                            // one string.
 
     if (ArgConfig::instance().option('V'))
     {
@@ -50,3 +35,14 @@ Command::Command()
         cerr << endl;
     }
 }
+
+
+
+
+
+
+
+
+
+
+
